<?php

namespace Drupal\paragraphs_browser_deploy\Commands;

use Drupal\paragraphs_browser_deploy\Services\ParagraphsBrowserDeploy;
use Drush\Commands\DrushCommands;

/**
 * Drush Commands for the module Paragraphs Browser Deploy.
 */
class ParagraphsBrowserCommands extends DrushCommands {

  /**
   * Paragraphs Browser Deploy Functions.
   *
   * @var \Drupal\paragraphs_browser_deploy\Services\ParagraphsBrowserDeploy
   */
  protected $paragraphsBrowserDeployFunctions;

  /**
   * TokenCommands constructor.
   *
   * @param \Drupal\paragraphs_browser_deploy\Services\ParagraphsBrowserDeploy $paragraphsBrowserDeployFunctions
   *   Paragraphs Browser Deploy Functions.
   */
  public function __construct(ParagraphsBrowserDeploy $paragraphsBrowserDeployFunctions) {
    parent::__construct();
    $this->paragraphsBrowserDeployFunctions = $paragraphsBrowserDeployFunctions;
  }

  /**
   * Update image of paragraphs browser.
   *
   * @command paragraphs-browser-deploy:deploy
   * @usage paragraphs-browser-deploy:deploy
   * @aliases pbdd
   */
  public function deploy() {
    $deploy = $this->paragraphsBrowserDeployFunctions->deploy(FALSE);
    if ($deploy) {
      $this->logger()->success(dt("Deploy of images of Paragraphs browser done."));
    }
    else {
      $this->logger()->error(dt("Impossible to create file."));
    }
  }

  /**
   * Update image of paragraphs browser and change browser image path.
   *
   * @command paragraphs-browser-deploy:change
   * @usage paragraphs-browser-deploy:change
   * @aliases pbdc
   */
  public function change() {
    $this->paragraphsBrowserDeployFunctions->deploy(TRUE);
    $this->logger()->success(dt("Deploy of images of Paragraphs browser and browser image uri change done."));
  }

}
