<?php

namespace Drupal\paragraphs_browser_deploy\Services;

use Drupal\Core\Config\ConfigFactory;
use Drupal\Core\Entity\EntityTypeBundleInfoInterface;
use Drupal\Core\Extension\ExtensionPathResolver;
use Drupal\Core\File\FileSystemInterface;
use Drupal\file\FileRepository;
use Drupal\paragraphs\Entity\ParagraphsType;

/**
 * Service of functions for Paragraphs Browser Deploy.
 */
class ParagraphsBrowserDeploy {

  /**
   * The entity type bundle info.
   *
   * @var \Drupal\Core\Entity\EntityTypeBundleInfoInterface
   */
  protected $entityTypeBundleInfo;

  /**
   * The extension path resolver.
   *
   * @var \Drupal\Core\Extension\ExtensionPathResolver
   */
  protected $extensionPathResolver;

  /**
   * The file repository service.
   *
   * @var \Drupal\file\FileRepository
   */
  protected $fileRepository;

  /**
   * Configuration object.
   *
   * @var \Drupal\Core\Config\Config
   */
  protected $config;

  /**
   * Filesystem.
   *
   * @var \Drupal\Core\File\FileSystemInterface
   */
  protected $fileSystem;

  /**
   * ParagraphsBrowserDeploy constructor.
   *
   * @param \Drupal\Core\Entity\EntityTypeBundleInfoInterface $entityTypeBundleInfo
   *   Entity type bundle info.
   * @param \Drupal\Core\Extension\ExtensionPathResolver $extension_path_resolver
   *   Extension Path Resolver.
   * @param \Drupal\file\FileRepository $fileRepository
   *   File Repository.
   * @param \Drupal\Core\Config\ConfigFactory $config_factory
   *   Config Factory.
   * @param \Drupal\Core\File\FileSystemInterface $fileSystem
   *   File System.
   */
  public function __construct(EntityTypeBundleInfoInterface $entityTypeBundleInfo, ExtensionPathResolver $extension_path_resolver, FileRepository $fileRepository, ConfigFactory $config_factory, FileSystemInterface $fileSystem) {
    $this->entityTypeBundleInfo = $entityTypeBundleInfo;
    $this->extensionPathResolver = $extension_path_resolver;
    $this->fileRepository = $fileRepository;
    $this->config = $config_factory->get('paragraphs_browser_deploy.settings');
    $this->fileSystem = $fileSystem;
  }

  /**
   * Deploy function.
   *
   * @param bool $change
   *   Allow to save path of image into settings paragraph url.
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  public function deploy(bool $change = FALSE) {
    $directory = 'public://paragraphs_image';
    $bundles = $this->entityTypeBundleInfo->getBundleInfo('paragraph');
    if ($this->fileSystem->prepareDirectory($directory, FileSystemInterface::CREATE_DIRECTORY)) {
      foreach ($bundles as $id => $bundle) {
        $filename = $id . '.png';
        $uri = $directory . '/' . $filename;
        $folder = $this->config->get('folder_img_origin');
        if (!$folder) {
          $folder = $this->extensionPathResolver->getPath('module', 'paragraphs_browser_deploy') . '/img';
        }
        $img = $folder . '/' . $filename;
        if (file_exists($img)) {
          $img_content = file_get_contents($img);
          if (file_exists($uri)) {
            $img_old = file_get_contents($uri);
            if (md5($img_content) !== md5($img_old)) {
              $this->saveImage($filename, $img_content);
            }
          }
          else {
            $this->saveImage($filename, $img_content);
          }
        }
        if ($change) {
          $paragraphs_type = ParagraphsType::load($id);
          if (file_exists($img)) {
            $paragraphs_type->setThirdPartySetting('paragraphs_browser', 'image_path', $uri);
          }
          else {
            $paragraphs_type->unsetThirdPartySetting('paragraphs_browser', 'image_path');
          }
          $paragraphs_type->save();
        }
      }
    }
    else {
      return FALSE;
    }
    return TRUE;
  }

  /**
   * Save image.
   *
   * @param string $filename
   *   The filename.
   * @param string $img_content
   *   Image content.
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  protected function saveImage(string $filename, string $img_content) {
    $file = $this->fileRepository->writeData($img_content, 'public://paragraphs_image/' . $filename, FileSystemInterface::EXISTS_REPLACE);
    $file->setPermanent();
    $file->save();
  }

}
